@@ -132,9 +132,18 @@ sub ACTION_code {
     return $self->SUPER::ACTION_code(@_);
 };
 
+sub ACTION_test_core {
+    my $self = shift;
+    $self->log_info("Testing CORE (ignoring results)\n");
+    $ENV{PERL_POSIX_STRFTIME_GNU_XS} = 0;
+    $ENV{PERL_POSIX_STRFTIME_GNU_PP} = 0;
+    return eval { $self->SUPER::ACTION_test(@_) };
+};
+
 sub ACTION_test_pp {
     my $self = shift;
     $self->log_info("Testing PP\n");
+    $ENV{PERL_POSIX_STRFTIME_GNU_XS} = 0;
     $ENV{PERL_POSIX_STRFTIME_GNU_PP} = 1;
     return $self->SUPER::ACTION_test(@_);
 };
@@ -142,12 +151,14 @@ sub ACTION_test_pp {
 sub ACTION_test_xs {
     my $self = shift;
     $self->log_info("Testing XS\n");
-    $ENV{PERL_POSIX_STRFTIME_GNU_PP} = 1;
+    $ENV{PERL_POSIX_STRFTIME_GNU_XS} = 1;
+    $ENV{PERL_POSIX_STRFTIME_GNU_PP} = 0;
     return $self->SUPER::ACTION_test(@_);
 };
 
 sub ACTION_test {
     my $self = shift;
+    $self->depends_on('test_core');
     $self->depends_on('test_pp');
     $self->depends_on('test_xs') unless $self->args('pp');
 };
